"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.help = exports.commandNames = exports.shorthands = exports.cliOptionsTypes = exports.rcOptionsTypes = void 0;
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const path_1 = __importDefault(require("path"));
const cli_utils_1 = require("@pnpm/cli-utils");
const render_help_1 = __importDefault(require("render-help"));
const rcOptionsTypes = () => ({});
exports.rcOptionsTypes = rcOptionsTypes;
const cliOptionsTypes = () => ({});
exports.cliOptionsTypes = cliOptionsTypes;
exports.shorthands = {};
exports.commandNames = ['setup'];
function help() {
    return render_help_1.default({
        description: 'Sets up pnpm',
        descriptionLists: [],
        url: cli_utils_1.docsUrl('setup'),
        usages: ['pnpm setup'],
    });
}
exports.help = help;
async function handler(opts) {
    const currentShell = process.env.SHELL ? path_1.default.basename(process.env.SHELL) : null;
    switch (currentShell) {
        case 'bash': {
            const configFile = path_1.default.join(os_1.default.homedir(), '.bashrc');
            return setupShell(configFile, opts.pnpmHomeDir);
        }
        case 'zsh': {
            const configFile = path_1.default.join(os_1.default.homedir(), '.zshrc');
            return setupShell(configFile, opts.pnpmHomeDir);
        }
        case 'fish': {
            return setupFishShell(opts.pnpmHomeDir);
        }
    }
    return 'Could not infer shell type.';
}
exports.handler = handler;
async function setupShell(configFile, pnpmHomeDir) {
    if (!fs_1.default.existsSync(configFile))
        return `Could not setup pnpm. No ${configFile} found`;
    const configContent = await fs_1.default.promises.readFile(configFile, 'utf8');
    if (configContent.includes('PNPM_HOME')) {
        return `PNPM_HOME is already in ${configFile}`;
    }
    await fs_1.default.promises.writeFile(configFile, `${configContent}
export PNPM_HOME="${pnpmHomeDir}"
export PATH="$PNPM_HOME:$PATH"
`, 'utf8');
    return `Updated ${configFile}`;
}
async function setupFishShell(pnpmHomeDir) {
    const configFile = path_1.default.join(os_1.default.homedir(), '.config/fish/config.fish');
    if (!fs_1.default.existsSync(configFile))
        return `Could not setup pnpm. No ${configFile} found`;
    const configContent = await fs_1.default.promises.readFile(configFile, 'utf8');
    if (configContent.includes('PNPM_HOME')) {
        return `PNPM_HOME is already in ${configFile}`;
    }
    await fs_1.default.promises.writeFile(configFile, `${configContent}
set -gx PNPM_HOME "${pnpmHomeDir}"
set -gx PATH "$PNPM_HOME" $PATH
`, 'utf8');
    return `Updated ${configFile}`;
}
//# sourceMappingURL=setup.js.map